==> php82-nextcloud-28.0.6.tgz: share/nextcloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Se ha detectado la configuración de muestra",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que la configuración de muestra ha sido copiada. Esto puede descomponer su instalacón y no está soportado. Favor de leer la documentación antes de hacer cambios en el archivo config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de Groupware",
    "Social sharing bundle" : "Paquete para compartir en redes sociales",
    "PHP %s or higher is required." : "Se requiere de PHPH %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferior a la %s es requerido. ",
    "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
    "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
    "The library %s is not available." : "La biblioteca %s no está disponible. ",
    "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
    "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerida. ",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Files" : "Archivos",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Favor de habilitarlo en sus configuraciones de aplicación o contacte a su administrador.  ",
    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
    "__language_name__" : "Español (Argentina)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
    "Apps" : "Aplicaciones",
    "Settings" : "Ajustes",
    "Log out" : "Cerrar sesión",
    "Users" : "Usuarios",
    "Email" : "Correo electrónico",
    "Phone" : "Teléfono fijo",
    "Twitter" : "Twitter",
    "Website" : "Sitio web",
    "Address" : "Dirección",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Additional settings" : "Configuraciones adicionales",
    "You need to enter details of an existing account." : "Necesita ingresar los detalles de una cuenta existente.",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Uselo bajo su propio riesgo!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, favor de cosiderar usar en su lugar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Favor de eliminar el ajuste open_basedir de su archivo php.ini o cambie a PHP de 64 bits. ",
    "Set an admin password." : "Establecer la contraseña del administrador.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
    "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
    "Open »%s«" : "Abrir »%s«",
    "You are not allowed to share %s" : "No tiene permitido compartir %s",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, favor de intentarlo más tarde. ",
    "Application is not enabled" : "La aplicación está deshabilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "La ficha ha expirado. Favor de recarga la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuenta con controladores de base de datos (sqlite, mysql o postgresql)  instalados. ",
    "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
    "Please ask your server administrator to install the module." : "Favor de solicitar a su adminsitrador la instalación del módulo. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
    "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
    "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
    "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
    "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
    "Help" : "Ayuda",
    "Unknown user" : "Ususario desconocido",
    "Oracle username and/or password not valid" : "El nombre de usuario y/o contraseña de Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "El nombre de usuario y/o contraseña de PostgreSQL inválidos",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
    "The username is already being used" : "Ese nombre de usuario ya está en uso",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre del usuario contiene un espacio en blanco al inicio o al final",
    "Username must not consist of dots only" : "El nombre de usuario no debe consistir de solo puntos. ",
    "User disabled" : "Usuario deshabilitado",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-30.0.11.tgz: share/nextcloud/lib/l10n/es_AR.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Se ha detectado la configuración de muestra",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que la configuración de muestra ha sido copiada. Esto puede descomponer su instalacón y no está soportado. Favor de leer la documentación antes de hacer cambios en el archivo config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de Groupware",
    "Social sharing bundle" : "Paquete para compartir en redes sociales",
    "PHP %s or higher is required." : "Se requiere de PHPH %s o superior.",
    "PHP with a version lower than %s is required." : "PHP con una versión inferior a la %s es requerido. ",
    "%sbit or higher PHP required." : "se requiere PHP para %sbit o superior.",
    "The command line tool %s could not be found" : "No fue posible encontar la herramienta de línea de comando %s",
    "The library %s is not available." : "La biblioteca %s no está disponible. ",
    "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
    "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerida. ",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Files" : "Archivos",
    "today" : "hoy",
    "yesterday" : "ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses","Hace %n meses"],
    "last year" : "año pasado",
    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Favor de habilitarlo en sus configuraciones de aplicación o contacte a su administrador.  ",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "Filename contains at least one invalid character" : "Nombre de archivo contiene al menos un carácter no válido",
    "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
    "__language_name__" : "Español (Argentina)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
    "Apps" : "Aplicaciones",
    "Settings" : "Ajustes",
    "Log out" : "Cerrar sesión",
    "Email" : "Correo electrónico",
    "Phone" : "Teléfono fijo",
    "Twitter" : "Twitter",
    "Website" : "Sitio web",
    "Address" : "Dirección",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Headline" : "Títular",
    "Organisation" : "Organización",
    "Role" : "Rol",
    "Pronouns" : "Pronombres",
    "Additional settings" : "Configuraciones adicionales",
    "You need to enter details of an existing account." : "Necesita ingresar los detalles de una cuenta existente.",
    "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, favor de cosiderar usar en su lugar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Favor de eliminar el ajuste open_basedir de su archivo php.ini o cambie a PHP de 64 bits. ",
    "Set an admin password." : "Establecer la contraseña del administrador.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
    "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
    "%1$s shared %2$s with you" : "%1$s ha compartido \"%2$s\" con usted",
    "Open %s" : "Abrir %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s le compartió %2$s y quiere añadir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s le compartió %2$s y quiere añadir",
    "%s added a note to a file shared with you" : "%s añadió una nota a un archivo compartido con Ud.",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "You are not allowed to share %s" : "No tiene permitido compartir %s",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
    "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
    "a safe home for all your data" : "un lugar seguro para todos sus datos",
    "Application is not enabled" : "La aplicación está deshabilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "La ficha ha expirado. Favor de recarga la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuenta con controladores de base de datos (sqlite, mysql o postgresql)  instalados. ",
    "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
    "Please ask your server administrator to install the module." : "Favor de solicitar a su adminsitrador la instalación del módulo. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
    "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
    "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta del almacenamiento. %s",
    "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
    "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
    "Text" : "Texto",
    "Summary" : "Resumen",
    "Translate" : "Traducir",
    "Result" : "Resultado",
    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Users" : "Usuarios",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
    "»%s« added a note to a file shared with you" : "%s añadió una nota a un archivo compartido con Ud.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, favor de intentarlo más tarde. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
